==> gcstar_0.5.0.orig.tar.gz: gcstar/lib/gcstar/GCLang/CS/GCModels/GCgames.pm <==
{
    package GCLang::CS::GCModels::GCgames;

    use utf8;
###################################################
#
#  Copyright 2005-2006 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Sbírka Her',
        Items => 'Hry',
        NewItem => 'Nová hra',
    
        Id => 'Id',
        Name => 'Název',
        Platform => 'Platforma',
        Players => 'Počet hráčů',
        Released => 'Datum vydání',
        Editor => 'Vydavatel',
        Genre => 'Žánr',
        Box => 'Obrázek obalu',
        Rating => 'Hodnocení',
        Completion => 'Dokončeno (%)',
        Description => 'Popis',
        Codes => 'Cheaty',
        Code => 'Cheat',
        Effect => 'Účel',
        Secrets => 'Tajemství',
        Location => 'Lokace',
        Screenshots => 'Snímek ze hry',
        Screenshot1 => 'První snímek ze hry',
        Screenshot2 => 'Druhý snímek ze hry',
        Url => 'Web',
        Unlockables => 'Možnosti odemčení',
        Unlockable => 'Odemčení',
        Howto => 'Jak odemknout',

        General => 'Hlavní',
        Details => 'Detaily',
        Tips => 'Tipy',
        Information => 'Informace',

        FilterRatingSelect => 'Hodnocení _minimálně...',
     );
}

1;

==> gcstar-1.6.0.tar.gz: gcstar/lib/gcstar/GCLang/CS/GCModels/GCgames.pm <==
{
    package GCLang::CS::GCModels::GCgames;

    use utf8;
###################################################
#
#  Copyright 2005-2010 Christian Jodar
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Sbírka her',
        Items => sub {
          my $number = shift;
          return 'Hra' if $number eq '1';
          return 'Hry' if $number =~ /(?<!1)[2-4]$/;
          return 'Her';
        },
        NewItem => 'Nová hra',
    
        Id => 'Id',
        Ean => 'EAN',
        Name => 'Název',
        Platform => 'Platforma',
        Players => 'Počet hráčů',
        Released => 'Datum vydání',
        Editor => 'Vydavatel',
        Developer => 'Vývojář',
        Genre => 'Žánr',
        Box => 'Obrázek obalu',
        Case => 'Obal',
        Manual => 'Manuál',
        Completion => 'Dokončeno (%)',
        Executable => 'Spustitelný soubor',
        Description => 'Popis',
        Codes => 'Cheaty',
        Code => 'Cheat',
        Effect => 'Účel',
        Secrets => 'Tajemství',
        Screenshots => 'Snímek ze hry',
        Screenshot1 => 'První snímek ze hry',
        Screenshot2 => 'Druhý snímek ze hry',
        Comments => 'Komentář',
        Url => 'Web',
        Unlockables => 'Možnosti odemčení',
        Unlockable => 'Odemčení',
        Howto => 'Jak odemknout',
        Exclusive => 'Exclusive',
        Resolutions => 'Display resolutions',
        InstallationSize => 'Size',

        General => 'Hlavní',
        Details => 'Detaily',
        Tips => 'Tipy',
        Information => 'Informace',

        FilterRatingSelect => 'Hodnocení _minimálně...',
     );
}

1;
